% [delta_upbot,delta_botup,is_inv_dens] = test_density14(P,T,S,threshold)
% 
% INPUT:
%
% P(1,nlevel) pression (dB)
% T(1,nlevel) T in situ (C)
% S(1,nlevel) S in situ (PSU)
% treshold : treshold used for detecting density inversion (0.03kg/m3)
%
% OUTPUT:
% delta_upbot (1,nlevel) : top to bottom test :  if delta_upbot >= 0.03kg/m3 flag 4 of the level i
% delta_botup (1,nlevel) : bottom to top test:  if delta_botup <= -0.03kg/m3 flag of the level i
% is_inv_dens (1,nlevel) : is_inv_dens=1 if level i should be flagued as bad (flag 4) ; ==0  otherwise

% You will need The ITS-90 version of the CSIRO SEAWATER library, which you can obtain from
% http://www.cmar.csiro.au/datacentre/ext_docs/seawater.htm.  Version 3.3   22-Sep-2010 
% 


function [delta_upbot,delta_botup,is_inv_dens] = test_density14(P,T,S,treshold)


if size(P,1)> 1
P=P';
end
if size(T,1)> 1
T=T';
end
if size(S,1)> 1
S=S';
end


%%
% From top to bottom :  two consecutive levels, i and i+1, are checked (Pi < Pi+1 )
%%
Pref = (P(1:end-1)+P(2:end))/2;


% rho_i(Pi, Ti, Si, Pref): potential density referenced to the mid-point Pref 

rhop_i = sw_pden(S(1:end-1),T(1:end-1),P(1:end-1),Pref);

% rho_ip1(Pi+1, Ti+1, Si+1, Pref): potential density referenced to the mid-point Pref 

rhop_ip1 = sw_pden(S(2:end),T(2:end),P(2:end),Pref);

delta_upbot = [rhop_i-rhop_ip1, NaN]; 



%%
% From bottom to top :  two consecutive levels, i and i+1, are checked (Pi > Pi+1 )
%%
Pref = (P(2:end)+P(1:end-1))/2;


% rho_i(Pi, Ti, Si, Pref): potential density referenced to the mid-point Pref 

rhop_i = sw_pden(S(2:end),T(2:end),P(2:end),Pref);

% rho_ip1(Pi+1, Ti+1, Si+1, Pref): potential density referenced to the mid-point Pref 

rhop_ip1 = sw_pden(S(1:end-1),T(1:end-1),P(1:end-1),Pref);

delta_botup = [NaN, rhop_i-rhop_ip1]; 


% test if there is density inversion with the 0.03kgm-3 criterion

is_inv_dens = delta_upbot>=treshold | delta_botup<=-treshold;



